@@ -1,7 +1,7 @@
 # Accelerator for pip, the Python package manager.
 #
 # Author: Peter Odding <peter.odding@paylogic.eu>
-# Last Change: November 15, 2014
+# Last Change: November 16, 2014
 # URL: https://github.com/paylogic/pip-accel
 
 """
@@ -19,12 +19,11 @@ which automatically disables backends that report errors.
 """
 
 # Standard library modules.
-import hashlib
 import logging
 
 # Modules included in our package.
-from pip_accel.config import cache_format_revision
-from pip_accel.utils import compact, get_python_version
+from pip_accel.exceptions import CacheBackendDisabledError
+from pip_accel.utils import get_python_version, sha1
 
 # External dependencies.
 from humanfriendly import concatenate, pluralize
@@ -53,14 +52,30 @@ class AbstractCacheBackend(object):
     archives in order to accelerate performance and gain independence of
     external systems like PyPI and distribution sites.
 
-    This base class automatically registers subclasses at definition time,
-    providing a simple and elegant registration mechanism for custom backends.
-    Based on the article `Using Metaclasses to Create Self-Registering Plugins
-    <http://effbot.org/zone/metaclass-plugins.htm>`_.
+    .. note:: This base class automatically registers subclasses at definition
+              time, providing a simple and elegant registration mechanism for
+              custom backends. This technique uses metaclasses and was
+              originally based on the article `Using Metaclasses to Create
+              Self-Registering Plugins
+              <http://effbot.org/zone/metaclass-plugins.htm>`_.
+
+              I've since had to introduce some additional magic to make this
+              mechanism compatible with both Python 2.x and Python 3.x because
+              the syntax for metaclasses is very much incompatible and I refuse
+              to write separate implementations for both :-).
     """
 
     PRIORITY = 0
 
+    def __init__(self, config):
+        """
+        Initialize a cache backend.
+
+        :param config: The pip-accel configuration (a :py:class:`.Config`
+                       object).
+        """
+        self.config = config
+
     def get(self, filename):
         """
         This method is called by pip-accel before fetching or building a
@@ -104,7 +119,7 @@ class CacheManager(object):
     exceptions on ``get()`` and ``put()`` operations.
     """
 
-    def __init__(self):
+    def __init__(self, config):
         """
         Initialize a cache manager.
 
@@ -112,74 +127,73 @@ class CacheManager(object):
         based on setuptools' support for entry points which makes it possible
         for external Python packages to register additional cache backends
         without any modifications to pip-accel.
+
+        :param config: The pip-accel configuration (a :py:class:`.Config`
+                       object).
         """
+        self.config = config
         for entry_point in get_entry_map('pip-accel', 'pip_accel.cache_backends').values():
             logger.debug("Importing cache backend: %s", entry_point.module_name)
             __import__(entry_point.module_name)
         # Initialize instances of all registered cache backends (sorted by
         # priority so that e.g. the local file system is checked before S3).
-        self.backends = sorted((b() for b in registered_backends if b != AbstractCacheBackend),
+        self.backends = sorted((b(self.config) for b in registered_backends if b != AbstractCacheBackend),
                                key=lambda b: b.PRIORITY)
         logger.debug("Initialized %s: %s",
-                     pluralize(len(self.backends), "cache backend", "cache backends"),
+                     pluralize(len(self.backends), "cache backend"),
                      concatenate(map(repr, self.backends)))
 
-    def get(self, package, version, url):
+    def get(self, requirement):
         """
         Get a distribution archive from any of the available caches.
 
-        :param package: The name of the package (a string).
-        :param version: The version of the package (a string).
-        :param url: The URL of the requirement (a string or ``None``).
+        :param requirement: A :py:class:`.Requirement` object.
         :returns: The absolute pathname of a local file or ``None`` when the
                   distribution archive is missing from all available caches.
         """
-        filename = self.generate_filename(package, version, url)
+        filename = self.generate_filename(requirement)
         for backend in list(self.backends):
             try:
                 pathname = backend.get(filename)
                 if pathname is not None:
                     return pathname
             except CacheBackendDisabledError as e:
-                logger.debug("Disabling %s because it requires configuration (%s).", backend, e)
+                logger.debug("Disabling %s because it requires configuration: %s", backend, e)
                 self.backends.remove(backend)
             except Exception as e:
                 logger.exception("Disabling %s because it failed: %s", backend, e)
                 self.backends.remove(backend)
 
-    def put(self, package, version, url, handle):
+    def put(self, requirement, handle):
         """
         Store a distribution archive in all of the available caches.
 
-        :param package: The name of the package (a string).
-        :param version: The version of the package (a string).
-        :param url: The URL of the requirement (a string or ``None``).
+        :param requirement: A :py:class:`.Requirement` object.
         :param handle: A file-like object that provides access to the
                        distribution archive.
         """
-        filename = self.generate_filename(package, version, url)
+        filename = self.generate_filename(requirement)
         for backend in list(self.backends):
             handle.seek(0)
             try:
                 backend.put(filename, handle)
             except CacheBackendDisabledError as e:
-                logger.debug("Disabling %s because it requires configuration (%s).", backend, e)
+                logger.debug("Disabling %s because it requires configuration: %s", backend, e)
                 self.backends.remove(backend)
             except Exception as e:
                 logger.exception("Disabling %s because it failed: %s", backend, e)
                 self.backends.remove(backend)
 
-    def generate_filename(self, package, version, url=None):
+    def generate_filename(self, requirement):
         """
         Generate a distribution archive filename for a package.
 
-        :param package: The name of the package (a string).
-        :param version: The version of the package (a string).
-        :param url: The URL of the requirement (a string or ``None``).
+        :param requirement: A :py:class:`.Requirement` object.
         :returns: The filename of the distribution archive (a string)
                   including a single leading directory component to indicate
                   the cache format revision.
         """
+        url = requirement.url
         if url and url.startswith('file://'):
             # Ignore the URL if it is a file:// URL because those frequently
             # point to temporary directories whose pathnames change with every
@@ -187,16 +201,8 @@ class CacheManager(object):
             # the cache key we would be generating a unique cache key on
             # every run (not good for performance ;-).
             url = None
-        tag = hashlib.sha1(str(version + url).encode()).hexdigest() if url else version
-        return 'v%i/%s:%s:%s.tar.gz' % (cache_format_revision, package, tag, get_python_version())
+        tag = sha1(requirement.version + url) if url else requirement.version
+        return 'v%i/%s:%s:%s.tar.gz' % (self.config.cache_format_revision,
+                                        requirement.name, tag, get_python_version())
 
-class CacheBackendError(Exception):
 
-    """Exception raised by cache backends when they fail in a controlled manner."""
-
-    def __init__(self, *args, **kw):
-        """Takes the same arguments as :py:func:`pip_accel.utils.compact()`."""
-        super(CacheBackendError, self).__init__(compact(*args, **kw))
-
-class CacheBackendDisabledError(Exception):
-    """Exception raised by cache backends when they require configuration."""
